@@ -218,7 +218,9 @@ static void appendPoints(Document* theDocument, CommandList* L, Way* Dest, Way*
     for (int i=1; i<srclen; ++i) {
         int j = (reverse ? srclen-i : i) - (prepend != reverse ? 1 : 0);
         Node* Pt = Src->getNode(j);
-        L->add(new AddFeatureCommand(layer, Pt, false));
+        if (!Pt->layer() || layer != Pt->layer()) {
+            L->add(new AddFeatureCommand(layer, Pt, false));
+        }
         L->add(new WayAddNodeCommand(Dest, Pt, destpos++, layer));
     }
 }
@@ -1658,12 +1660,12 @@ static bool axisAlignPreprocess(/* in */ PropertiesDock *theDock, const Projecti
         Node *n1;
         Node *n2 = theWay->getNode(0);
         QPointF p1;
-        QPointF p2 = proj.project(n2);
+        QPointF p2 = proj.project(n2->position());
         for (int j = 0; j < theWay->size()-1; ++j, ++i) {
             n1 = n2;
             n2 = theWay->getNode(j + 1);
             p1 = p2;
-            p2 = proj.project(n2);
+            p2 = proj.project(n2->position());
             if (n1 == n2 || p1 == p2) {
                 qWarning() << "ERROR: duplicate nodes found during axis align in" << theWay->id().numId;
                 return false;
@@ -1863,7 +1865,7 @@ AxisAlignResult axisAlignRoads(Document* theDocument, CommandList* theList, Prop
             Node *N = theWay->getNode(i);
             if (!dups && node_pos.contains(N) && !(theWay->isClosed() && i == theWay->size()-1))
                 dups = true;
-            node_pos[N] = proj.project(N);
+            node_pos[N] = proj.project(N->position());
         }
     }
 
@@ -1983,7 +1985,7 @@ AxisAlignResult axisAlignRoads(Document* theDocument, CommandList* theList, Prop
     foreach (Way *theWay, theWays) {
         for (int i = 0; i < theWay->size(); ++i) {
             Node *N = theWay->getNode(i);
-            theList->add(new MoveNodeCommand(N, proj.inverse2Coord(node_pos[N]), theDocument->getDirtyOrOriginLayer(N->layer())));
+            theList->add(new MoveNodeCommand(N, proj.inverse(node_pos[N]), theDocument->getDirtyOrOriginLayer(N->layer())));
         }
     }
     return AxisAlignSuccess;
