@@ -514,7 +514,7 @@ void MapView::drawLatLonGrid(QPainter & P)
             continue;
 //        QPoint pt = QPoint(0, p->theTransform.map(parallelLines.at(i).at(0)).y());
         QPoint ptt = pt.toPoint() + QPoint(5, -5);
-        P.drawText(ptt, QString("%1").arg(p->theProjection.inverse2Coord(parallelLines.at(i).at(0)).y(), 0, 'f', 2-prec));
+        P.drawText(ptt, QString("%1").arg(p->theProjection.inverse(parallelLines.at(i).at(0)).y(), 0, 'f', 2-prec));
     }
     for (int i=0; i<medianLines.size(); ++i) {
 
@@ -534,7 +534,7 @@ void MapView::drawLatLonGrid(QPainter & P)
             continue;
 //        QPoint pt = QPoint(p->theTransform.map(medianLines.at(i).at(0)).x(), 0);
         QPoint ptt = pt.toPoint() + QPoint(5, 10);
-        P.drawText(ptt, QString("%1").arg(p->theProjection.inverse2Coord(medianLines.at(i).at(0)).x(), 0, 'f', 2-prec));
+        P.drawText(ptt, QString("%1").arg(p->theProjection.inverse(medianLines.at(i).at(0)).x(), 0, 'f', 2-prec));
     }
 
     P.restore();
@@ -760,7 +760,7 @@ QPoint MapView::toView(Node* aPt) const
 
 Coord MapView::fromView(const QPoint& aPt) const
 {
-    return p->theProjection.inverse2Coord(p->theInvertedTransform.map(QPointF(aPt)));
+    return p->theProjection.inverse(p->theInvertedTransform.map(QPointF(aPt)));
 }
 
 
